darkhistory.spec.transferfunction.TransFuncAtRedshift
=====================================================

.. currentmodule:: darkhistory.spec.transferfunction

.. autoclass:: TransFuncAtRedshift

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~TransFuncAtRedshift.__init__
      ~TransFuncAtRedshift.append
      ~TransFuncAtRedshift.at_eng
      ~TransFuncAtRedshift.at_in_eng
      ~TransFuncAtRedshift.at_rs
      ~TransFuncAtRedshift.at_val
      ~TransFuncAtRedshift.integrate_each_spec
      ~TransFuncAtRedshift.plot
      ~TransFuncAtRedshift.rebin
      ~TransFuncAtRedshift.redshift
      ~TransFuncAtRedshift.sum_specs
      ~TransFuncAtRedshift.switch_spec_type
      ~TransFuncAtRedshift.totN
      ~TransFuncAtRedshift.toteng
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~TransFuncAtRedshift.N_underflow
      ~TransFuncAtRedshift.eng
      ~TransFuncAtRedshift.eng_underflow
      ~TransFuncAtRedshift.grid_vals
      ~TransFuncAtRedshift.in_eng
      ~TransFuncAtRedshift.rs
      ~TransFuncAtRedshift.spec_type
   
   